Preprocessor is reponsible for identifying the required values. This will be most abstract layer of the preprocessor.
Modules
- compile
- module_
compile - is causing too much overhead interms of abstraction around legacy types that we supported. Ideally later this file will deprecate ./compile
- module_
registry - Module registry is a service that provides the ability to fetch modules from the StarkNet network. It fetch contract class from the StarkNet network and compile it to the casm.